import { ControllerMetadataArgs } from '../metadata/args/ControllerMetadataArgs';
import { ActionMetadataArgs } from '../metadata/args/ActionMetadataArgs';
import { ParamMetadataArgs } from '../metadata/args/ParamMetadataArgs';
import { ResponseHandlerMetadataArgs } from '../metadata/args/ResponseHandleMetadataArgs';
import { MiddlewareMetadataArgs } from '../metadata/args/MiddlewareMetadataArgs';
import { UseMetadataArgs } from '../metadata/args/UseMetadataArgs';
import { UseInterceptorMetadataArgs } from '../metadata/args/UseInterceptorMetadataArgs';
import { InterceptorMetadataArgs } from '../metadata/args/InterceptorMetadataArgs';
import { Newable } from '../types/Types';
/**
 * Storage all metadatas read from decorators.
 */
export declare class MetadataArgsStorage {
    /**
     * Registered controller metadata args.
     */
    controllers: ControllerMetadataArgs[];
    /**
     * Registered middleware metadata args.
     */
    middlewares: MiddlewareMetadataArgs[];
    /**
     * Registered interceptor metadata args.
     */
    interceptors: InterceptorMetadataArgs[];
    /**
     * Registered "use middleware" metadata args.
     */
    uses: UseMetadataArgs[];
    /**
     * Registered "use interceptor" metadata args.
     */
    useInterceptors: UseInterceptorMetadataArgs[];
    /**
     * Registered action metadata args.
     */
    actions: ActionMetadataArgs[];
    /**
     * Registered param metadata args.
     */
    params: ParamMetadataArgs[];
    /**
     * Registered response handler metadata args.
     */
    responseHandlers: ResponseHandlerMetadataArgs[];
    /**
     * Filters registered middlewares by a given classes.
     */
    filterMiddlewareMetadatasForClasses(classes: Newable[]): MiddlewareMetadataArgs[];
    /**
     * Filters registered interceptors by a given classes.
     */
    filterInterceptorMetadatasForClasses(classes: Newable[]): InterceptorMetadataArgs[];
    /**
     * Filters registered controllers by a given classes.
     */
    filterControllerMetadatasForClasses(classes: Newable[]): ControllerMetadataArgs[];
    /**
     * Filters registered actions by a given classes.
     */
    filterActionsWithTarget(target: Newable): ActionMetadataArgs[];
    /**
     * Filters registered "use middlewares" by a given target class and method name.
     */
    filterUsesWithTargetAndMethod(target: Newable, methodName?: string): UseMetadataArgs[];
    /**
     * Filters registered "use interceptors" by a given target class and method name.
     */
    filterInterceptorUsesWithTargetAndMethod(target: Newable, methodName?: string): UseInterceptorMetadataArgs[];
    /**
     * Filters parameters by a given classes.
     */
    filterParamsWithTargetAndMethod(target: Newable, methodName: string): ParamMetadataArgs[];
    /**
     * Filters response handlers by a given class.
     */
    filterResponseHandlersWithTarget(target: Newable): ResponseHandlerMetadataArgs[];
    /**
     * Filters response handlers by a given classes.
     */
    filterResponseHandlersWithTargetAndMethod(target: Newable, methodName: string): ResponseHandlerMetadataArgs[];
    /**
     * Removes all saved metadata.
     */
    reset(): void;
}
